<?php
/**
*
* @author FreakyBlue (David Jansen) freakyblue@idlaunch.org
* @package Download Centre
* @version $Id includes/acp/acp_downloadcentre.php 0.0.6 2010-03-06 21:45:43GMT FreakyBlue $
* @copyright (c) 2009 FreakyBlue | http://www.IDLaunch.org
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

/**
* @ignore
*/

if (!defined('IN_PHPBB'))
{
	exit;
}

/**
* @package acp
*/

class acp_downloadcentre
{
	var $u_action;
	
	function main($id, $mode)
	{
		global $db, $user, $auth, $template, $cache;
		global $config, $downloadcentre_root_path, $phpbb_root_path, $phpbb_admin_path, $phpEx;
		$downloadcentre_root_path = DOWNLOADCENTRE_ROOT_PATH;
		
		include($phpbb_root_path . 'includes/acp/info/acp_downloadcentre.' . $phpEx);
		
		/*
		* Let's include the download centre module
		*/
		$user->add_lang('acp/common');
		$this->tpl_name = 'acp_downloadcentre';
		$this->page_title = $user->lang['ACP_DOWNLOADCENTRE_MANAGER'];
		
		// Define the form key
		$form_name = 'acp_downloadcentre';
		add_form_key($form_name);
		
		// Set up some general vars we need
		$action  = request_var('action', '');
		$action	 = (isset($_POST['add'])) ? 'add' : $action;
		$action	 = (isset($_POST['save'])) ? 'save' : $action;
		$action	 = (isset($_POST['attachment'])) ? 'attachment' : $action;
		$action	 = (isset($_POST['edit_attachment'])) ? 'edit_attachment' : $action;
		$attach_id = request_var('id', 0);
		$download_cat_id = request_var('id', 0);
		$download_cat_forums = request_var('forum', 0);
		
		// Install and update the Download Centre MOD through the ACP file
    	$version = new acp_downloadcentre_info();
		
		$downloadcentre_version = $version->module();
		$downloadcentre_version = $downloadcentre_version['version'];
		
		if (!isset($config['downloadcentre_version']))
		{
			$version->install($this->u_action);
		}
		else if (version_compare($config['downloadcentre_version'], $downloadcentre_version, '<'))
		{
			$version->update($this->u_action);
		}
		
		// Check the MOD version
		if (!function_exists('mod_version_check'))
		{
			include($phpbb_root_path . $downloadcentre_root_path . 'includes/functions_version_check.' . $phpEx);
		}
		mod_version_check();

		// There we go, we need some action
		switch ($action)
		{
			// Let's manage the download category save part first
			case 'save':
			
				// Check the form key, set at the beginning
				if (!check_form_key($form_name))
				{
					trigger_error($user->lang['FORM_INVALID'] . adm_back_link($this->u_action), E_USER_WARNING);
				}
				
				// Get all the data so we can show it
				$download_cat_title 		= utf8_normalize_nfc(request_var('download_cat_title', '', true));
				$download_cat_desc 			= utf8_normalize_nfc(request_var('download_cat_desc', '', true));
				$download_cat_image			= request_var('download_cat_image', '');
				$download_cat_order			= request_var('download_cat_order', 0);
				$download_cat_forums		= implode(',', request_var('download_cat_forums', array(0)));
				$download_cat_preview		= request_var('download_cat_preview', 0);
				$download_cat_exclude		= utf8_normalize_nfc(request_var('download_cat_exclude', '', true));
				
				// Check these fields concerning the download category. We don't want empty ones.
				if (!$download_cat_title)
				{
					trigger_error($user->lang['ACP_NO_DOWNLOAD_CAT_TITLE'] . adm_back_link($this->u_action), E_USER_WARNING);
				}
				
				if (!$download_cat_desc)
				{
					trigger_error($user->lang['ACP_NO_DOWNLOAD_CAT_DESC'] . adm_back_link($this->u_action), E_USER_WARNING);
				}
				
				// Remove whitespace from the exclude files input just in case
				$download_cat_exclude = str_replace(' ', '',($download_cat_exclude));
				
				// Prepare the storage SQL array
				$sql_ary = array(
					'download_cat_title'				=> $download_cat_title,
					'download_cat_desc'					=> $download_cat_desc,
					'download_cat_image'				=> $download_cat_image,
					'download_cat_order'				=> $download_cat_order,
					'download_cat_forums'				=> $download_cat_forums,
					'download_cat_preview'				=> $download_cat_preview,
					'download_cat_exclude'				=> $download_cat_exclude,
				);
				
				// Is this an update or a new download category?
				if ($download_cat_id)
				{
					$sql = 'UPDATE ' . DOWNLOADCENTRE_CAT_TABLE . '
					SET ' . $db->sql_build_array('UPDATE', $sql_ary) . "
					WHERE download_cat_id = $download_cat_id";
					$message = $user->lang['ACP_DOWNLOAD_CAT_UPDATED'];

					add_log('admin', 'ACP_LOG_DOWNLOAD_CAT_UPDATED', $download_cat_title);
				}
				else
				{
					$sql = 'INSERT INTO ' . DOWNLOADCENTRE_CAT_TABLE . ' ' . $db->sql_build_array('INSERT', $sql_ary);
					$message = $user->lang['ACP_DOWNLOAD_CAT_ADDED'];

					add_log('admin', 'ACP_LOG_DOWNLOAD_CAT_ADDED', $download_cat_title);
				}
				$db->sql_query($sql);

				trigger_error($message . adm_back_link($this->u_action));

			break;
			
			// Let's manage the delete part of the download categories
			case 'delete':
			
				// Check if there is an download category to delete
				if (!$download_cat_id)
				{
					trigger_error($user->lang['ACP_MUST_SELECT_DOWNLOAD_CAT'] . adm_back_link($this->u_action), E_USER_WARNING);
				}

				// Confirm deletion
				if (confirm_box(true))
				{
					$sql = 'SELECT download_cat_title
						FROM ' . DOWNLOADCENTRE_CAT_TABLE . '
						WHERE download_cat_id = ' . $download_cat_id;
					$result = $db->sql_query($sql);
					$download_cat_title = (string) $db->sql_fetchfield('download_cat_title');
					$db->sql_freeresult($result);

					$sql = 'DELETE FROM ' . DOWNLOADCENTRE_CAT_TABLE . "
						WHERE download_cat_id = $download_cat_id";
					$db->sql_query($sql);
					
					add_log('admin', 'ACP_LOG_DOWNLOAD_CAT_REMOVED', $download_cat_title);
				}
				else
				{
					confirm_box(false, $user->lang['CONFIRM_OPERATION'], build_hidden_fields(array(
						'i'					=> $id,
						'mode'				=> $mode,
						'attach_cat_id'		=> $download_cat_id,
						'action'			=> 'delete',
					)));
				}
				
			break;
			
			// Here we manage the add and edit part of download categories
			case 'edit':
			case 'add':
			
				$data = $download_cats = array();
				
				$sql = 'SELECT *
						FROM ' . DOWNLOADCENTRE_CAT_TABLE .'';
						$result = $db->sql_query($sql);

				// If we want to edit the download category, get the relevant data
				while ($row = $db->sql_fetchrow($result))
				{
					if ($action == 'edit' && $download_cat_id == $row['download_cat_id'])
					{
						$download_cat = $row;
					}
				}
				$db->sql_freeresult($result);

				// Assign already existing data
				$template->assign_vars(array(
					'S_EDIT'			=> true,
					'S_ADD'       		=> ($action == 'add') ? true : false,
					'U_BACK'			=> $this->u_action,
					'U_ACTION'			=> $this->u_action . '&amp;id=' . $download_cat_id,

					'DOWNLOAD_CAT_EDIT_TITLE'		=> (isset($download_cat['download_cat_title'])) ? $download_cat['download_cat_title'] : '',
					'DOWNLOAD_CAT_DESC'				=> (isset($download_cat['download_cat_desc'])) ? $download_cat['download_cat_desc'] : '',
					'DOWNLOAD_CAT_IMAGE'			=> (isset($download_cat['download_cat_image'])) ? $download_cat['download_cat_image'] : '',
					'DOWNLOAD_CAT_IMAGE_SRC'		=> (isset($download_cat['download_cat_image'])) ? $phpbb_root_path . $download_cat['download_cat_image'] : '',
					'DOWNLOAD_CAT_ORDER'			=> (isset($download_cat['download_cat_order'])) ? $download_cat['download_cat_order'] : 0,
					'DOWNLOAD_CAT_PREVIEW'			=> (isset($download_cat['download_cat_preview'])) ? $download_cat['download_cat_preview'] : '',
					'DOWNLOAD_CAT_EXCLUDE'			=> (isset($download_cat['download_cat_exclude'])) ? $download_cat['download_cat_exclude'] : '',
					
				));
				
			break;
			
			// Here we take care of the attachments part
			case 'attachment':
			
				// Check the form key, set at the beginning
				if (!check_form_key($form_name))
				{
					trigger_error($user->lang['FORM_INVALID'] . adm_back_link($this->u_action), E_USER_WARNING);
				}
				
				// Get all the data
				$attach_name				= utf8_normalize_nfc(request_var('real_filename', '', true));
				$attach_desc	 			= utf8_normalize_nfc(request_var('attach_comment', '', true));
				
				// Check the fields concerning the attachments. We don't want empty ones.
				if (!$attach_name)
				{
					trigger_error($user->lang['ACP_NO_ATTACH_NAME'] . adm_back_link($this->u_action), E_USER_WARNING);
				}
				
				if (!$attach_desc)
				{
					trigger_error($user->lang['ACP_NO_ATTACH_DESC'] . adm_back_link($this->u_action), E_USER_WARNING);
				}
				
				// Prepare the storage SQL array
				$sql_ary = array(
					'real_filename'					=> $attach_name,
					'attach_comment'				=> $attach_desc,
				);
				
				// Here we only need to update the attachment information because we don't add any in the acp-module
				if ($attach_id)
				{
					$sql = 'UPDATE ' . ATTACHMENTS_TABLE . '
					SET ' . $db->sql_build_array('UPDATE', $sql_ary) . "
					WHERE attach_id = $attach_id";
					$message = $user->lang['ACP_ATTACH_UPDATED'];

					add_log('admin', 'ACP_LOG_ATTACH_UPDATED', $attach_name);
				}
				$db->sql_query($sql);

				trigger_error($message . adm_back_link($this->u_action));

			break;
			
			// We need this to delete attachments if we want to
			case 'dump_attachment':

				// Check if there is a attachment to delete
				if (!$attach_id)
				{
					trigger_error($user->lang['ACP_MUST_SELECT_ATTACH'] . adm_back_link($this->u_action), E_USER_WARNING);
				}

				// Confirm deletion
				if (confirm_box(true))
				{
					$sql = 'SELECT attach_id
							FROM ' . ATTACHMENTS_TABLE . '
							WHERE attach_id = ' . $attach_id;
							$result = $db->sql_query($sql);
							$attach_id = (string) $db->sql_fetchfield('attach_id');
							$db->sql_freeresult($result);

					delete_attachments($attach_id, $attach_id, $resync = true);
					
					add_log('admin', 'ACP_LOG_ATTACH_REMOVED', $attach_id);
				}
				else
				{
					confirm_box(false, $user->lang['CONFIRM_OPERATION'], build_hidden_fields(array(
						'i'					=> $id,
						'mode'				=> $mode,
						'attach_id'			=> $attach_id,
						'action'			=> 'dump_attachment',
					)));
				}
				
			break;
			
			// Let's manage the edit part of the attachments
			case 'edit_attachment':
			
				$data = $attachs = array();
				
				$sql = 'SELECT *
						FROM ' . ATTACHMENTS_TABLE .'';
				$result = $db->sql_query($sql);

				// If we want to edit the attachments, get the relevant data
				while ($row = $db->sql_fetchrow($result))
				{
					if ($action == 'edit_attachment' && $attach_id == $row['attach_id'])
					{
						$attach = $row;
					}
				}
				$db->sql_freeresult($result);

				// Assign already existing data
				$template->assign_vars(array(
					'S_EDIT_ATTACHMENT'			=> true,
					'U_BACK'					=> $this->u_action,
					'U_ACTION'					=> $this->u_action . '&amp;id=' . $attach_id,

					'ATTACH_EDIT_NAME'			=> (isset($attach['real_filename'])) ? $attach['real_filename'] : '',
					'ATTACH_DESC'				=> (isset($attach['attach_comment'])) ? $attach['attach_comment'] : '',
				));
				
			break;
			
		}
				
		// Get the download forums and explode them properly
		$sql = 'SELECT download_cat_forums
     			FROM ' . DOWNLOADCENTRE_CAT_TABLE . '
				WHERE download_cat_id = ' . $download_cat_id . '';
				$result = $db->sql_query($sql);
				$row = $db->sql_fetchrow($result);
				
				$download_forums = explode(',', $row['download_cat_forums']);
				
				$template->assign_vars(array(
				'S_SELECT_FORUMS' 		=> make_forum_select(explode(',', $row['download_cat_forums'])),
				));
			
				$db->sql_freeresult($result);
		
		// Let's get the download categories data from the database
		$sql = 'SELECT download_cat_id, download_cat_title, download_cat_desc, download_cat_order, download_cat_forums, download_cat_preview, download_cat_exclude
				FROM ' . DOWNLOADCENTRE_CAT_TABLE . '
				GROUP BY download_cat_id
				ORDER BY download_cat_order ASC';
				$result = $db->sql_query($sql);
				while ($row = $db->sql_fetchrow($result))
		{
			// Now we have done this, add the template vars for the download categories
			$template->assign_block_vars('download_cat', array(
			'DOWNLOAD_CAT_ID'			=> $row['download_cat_id'],
			'DOWNLOAD_CAT_TITLE'		=> $row['download_cat_title'],
			'DOWNLOAD_CAT_DESC'			=> $row['download_cat_desc'],
			'DOWNLOAD_CAT_ORDER'		=> $row['download_cat_order'],
			'DOWNLOAD_CAT_PREVIEW'		=> $row['download_cat_preview'],
			'DOWNLOAD_CAT_EXCLUDE'		=> $row['download_cat_exclude'],
		
			'U_EDIT'				=> $this->u_action . '&amp;action=edit&amp;id=' . $row['download_cat_id'],
			'U_DELETE'				=> $this->u_action . '&amp;action=delete&amp;id=' . $row['download_cat_id'],
			));
			
		}		
			$db->sql_freeresult($result);
		
		// Let's get the attachment data from the database
		$sql = 'SELECT a.attach_id, a.topic_id, a.real_filename, a.filesize, a.poster_id, a.attach_comment, a.filetime, u.username, u.user_colour,	
				t.topic_title, t.topic_id, t.forum_id, d.download_cat_id
     			FROM ' . ATTACHMENTS_TABLE . ' a, ' . TOPICS_TABLE . ' t, ' . USERS_TABLE . ' u, ' . DOWNLOADCENTRE_CAT_TABLE . ' d
				WHERE u.user_id = a.poster_id
       			AND a.topic_id = t.topic_id
       			AND a.in_message = 0
				AND d.download_cat_id = ' . $download_cat_id . '
				AND ' . $db->sql_in_set('t.forum_id', $download_forums) . '
				ORDER BY a.filetime DESC';
				$result = $db->sql_query($sql);
				while ($row = $db->sql_fetchrow($result))
			{
				// Now we have done this, add the template vars
				$template->assign_block_vars('attachment', array(
				'ATTACH_ID'					=> $row['attach_id'],
				'REALNAME'					=> $row['real_filename'],
				'DESC'						=> $row['attach_comment'],
				'TOPIC_NAME'				=> $row['topic_title'],
				'TOPIC_URL'					=> append_sid($phpbb_root_path . 'viewtopic.' . $phpEx, 't=' . $row['topic_id']),
				'DATE'						=> $user->format_date($row['filetime'], 'D M d, Y g:i a'),
				'SIZE'						=> get_formatted_filesize($row['filesize']),
				'POSTER'					=> get_username_string('full', $row['poster_id'], $row['username'], $row['user_colour']),

				'U_FILE'					=> append_sid($phpbb_root_path . 'download/file.' . $phpEx, 'id=' . $row['attach_id']),
				'U_EDIT_ATTACHMENT'			=> $this->u_action . '&amp;action=edit_attachment&amp;id=' . $row['attach_id'],
				'U_DUMP_ATTACHMENT'			=> $this->u_action . '&amp;action=dump_attachment&amp;id=' . $row['attach_id'],
				));
				
			}
				$db->sql_freeresult();
				
				$template->assign_vars(array(
				'DOWNLOAD_PAGE_VERSION'		=> 'v' . $config['downloadcentre_version'],
				));
		
		}
	}

?>